package com.ruoyi.invest.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.invest.domain.Accounts;
import com.ruoyi.invest.domain.vo.AccountsVo;
import com.ruoyi.invest.domain.dto.AccountsDto;
import com.ruoyi.invest.service.IAccountsService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 记账账户Controller
 *
 * @author tianyongbao
 * @date 2024-03-30
 */
@Api(tags=" 记账账户")
@RestController
@RequestMapping("/accounts")
public class AccountsController extends BaseController
{
    @Resource
    private IAccountsService accountsService;

    /**
     * 查询记账账户列表
     */
    @ApiOperation(value="查询记账账户列表",response = AccountsVo.class)
    @RequiresPermissions("invest:accounts:list")
    @GetMapping("/list")
    public TableDataInfo list(AccountsDto accountsDto)
    {
        startPage();
        List<AccountsVo> list = accountsService.selectAccountsList(accountsDto);
        return getDataTable(list);
    }

    /**
     * 导出记账账户列表
     */
    @ApiOperation(value="导出记账账户列表")
    @RequiresPermissions("invest:accounts:export")
    @Log(title = "记账账户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AccountsDto accountsDto)
    {
        List<AccountsVo> list = accountsService.selectAccountsList(accountsDto);
        ExcelUtil<AccountsVo> util = new ExcelUtil<AccountsVo>(AccountsVo.class);
        util.exportExcel(response, list, "记账账户数据");
    }

    /**
     * 获取记账账户详细信息
     */
    @ApiOperation(value="获取记账账户详细信息")
    @RequiresPermissions("invest:accounts:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(accountsService.selectAccountsById(id));
    }

    /**
     * 新增记账账户
     */
    @ApiOperation(value="新增记账账户")
    @RequiresPermissions("invest:accounts:add")
    @Log(title = "记账账户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Accounts accounts)
    {
        return toAjax(accountsService.insertAccounts(accounts));
    }

    /**
     * 修改记账账户
     */
    @ApiOperation(value="修改记账账户")
    @RequiresPermissions("invest:accounts:edit")
    @Log(title = "记账账户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Accounts accounts)
    {
        return toAjax(accountsService.updateAccounts(accounts));
    }

    /**
     * 删除记账账户
     */
    @ApiOperation(value="删除记账账户")
    @RequiresPermissions("invest:accounts:remove")
    @Log(title = "记账账户", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(accountsService.deleteAccountsByIds(ids));
    }
}
